@@ -1,4 +1,5 @@
 """Utility functions for snapchat_dl."""
+import json
 import os
 import re
 from argparse import Namespace
@@ -35,7 +36,7 @@ def valid_username(username):
     Returns:
         bool: True if username is valid.
     """
-    match = re.match(r"(?P<username>^[\w\.\_]{3,}$)", username)
+    match = re.match(r"(?P<username>^[\-\w\.\_]{3,15}$)", username)
     if match is None:
         return False
 
@@ -51,13 +52,20 @@ def search_usernames(string: str) -> list:
     Returns:
         list: usernames found in string
     """
-    return [
-        username
-        for username in re.findall(
-            r"https://story.snapchat.com/s/([\w_\.]{3,})", string
+    return list(
+        sorted(
+            set(
+                [
+                    username
+                    for username in re.findall(
+                        r"https?://(?:story|www).snapchat.com/(?:[suad]+/|@)([\-\w\.\_]{3,15})",
+                        string,
+                    )
+                    if valid_username(username)
+                ]
+            )
         )
-        if valid_username(username)
-    ]
+    )
 
 
 def use_batch_file(args: Namespace) -> list:
@@ -112,4 +120,35 @@ def use_prefix_dir(args: Namespace):
                 "Added {} usernames from {}".format(len(usernames), args.save_prefix)
             )
 
-    return usernames
+    return list(sorted(set(usernames)))
+
+
+def dump_text_file(content: str, filepath: str):
+    """Write content to filepath using `tx` mode.
+
+    Args:
+        content (str): File content to write.
+        filepath (str): Filepath.
+
+    This will overwrite the file.
+    """
+    dirpath = os.path.dirname(filepath)
+
+    os.makedirs(dirpath, exist_ok=True)
+
+    if not os.path.isfile(filepath):
+        with open(filepath, "w+") as f:
+            f.write(content)
+
+
+def dump_response(content: dict, path: str):
+    """Save JSON file
+
+    Args:
+        content: JSON data
+        path: Path to save json
+
+    Returns:
+        None
+    """
+    dump_text_file(json.dumps(content), path)
